Bindings Documentation
======================
   
.. note::

	The python-stix bindings are auto-generated - see :doc:`../api_vs_bindings/index` for more details. The bindings documentation may be incomplete and/or inconsistent. Please bear with us as we determine the best solution for this documentation.